package com.softwarereality.customer;

import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.event.*;
import javax.swing.*;

/**
 * Swing panel to view and edit customer details.
 */
public class CustomerDetailsPanel extends JPanel implements CustomerDetailsUI {
    
    private JFrame parentFrame;
    private CustomerDetailsController controller;
    private JTextField customerIDField;
    
    public CustomerDetailsPanel(JFrame parentFrame, String customerID) {
        this.parentFrame = parentFrame;
        controller = new CustomerDetailsController(this);
        initGUI();
        controller.initApp(customerID);
        addListeners();
    }

    private void indicateValidCustomerIDField() {
        customerIDField.setBackground(defaultTextFieldBG);
        customerIDField.setToolTipText(null);
    }
    private Color defaultTextFieldBG;
    
    private void highlightInvalidCustomerIDField(String errorTooltip) {
        customerIDField.setBackground(Color.RED);
        customerIDField.requestFocus();
        customerIDField.setToolTipText(errorTooltip);
    }
    
    // implements CustomerDetailsUI
    public  void populateUIFromData() {
        customerIDField.setText(controller.getCustomer().getId());
    }
    
    
    private void initGUI() {
        setLayout(new FlowLayout());
        customerIDField = new JTextField();
        customerIDField.setColumns(10);
        defaultTextFieldBG = customerIDField.getBackground();
        indicateValidCustomerIDField();
        
        add(new JLabel("Customer ID:"));
        add(customerIDField);
    }
    
    private boolean validateCustomerIDField() {
        try {
            String id = customerIDField.getText();
            controller.validateCustomerID(id);
            indicateValidCustomerIDField();
            return true;
        } catch (IllegalArgumentException e) {
            highlightInvalidCustomerIDField(e.getMessage());
            return false;
        }
    }
    
    private void addListeners() {
        customerIDField.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
                validateCustomerIDField();
            }
        });
        
        parentFrame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent event) {
                if (validateCustomerIDField()) {
                    parentFrame.setVisible(false);
                    System.exit(0);
                }
            }
            public void windowClosed(WindowEvent event) {
            }
        });
        
    }
    
    public static void main(String[] args) {
        JFrame frame = new JFrame("Customer Details");
        frame.setContentPane(new CustomerDetailsPanel(frame, "AB1234"));
        frame.setSize(350, 200);
        frame.setLocationRelativeTo(null); // centre frame on the screen
        frame.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
        frame.setVisible(true);
    }

}
