package test.com.softwarereality.customer;

import com.softwarereality.customer.*;
import junit.framework.TestCase;

/**
 * Tests the CustomerDetailsController.
 */
public class CustomerDetailsTest extends TestCase {
    
    private CustomerDetailsController controller;
    
    public void setUp() throws Exception {
        super.setUp();
        CustomerDetailsUI ui = new MockCustomerDetailsUI();
        controller = new CustomerDetailsController(ui);
    }
    
    public void tearDown() throws Exception {
        controller = null;
    }
    
    public void testValidAccountID() {
        try {
            controller.validateCustomerID("abcd");
        } catch (IllegalArgumentException e) {
            fail("Valid account ID shouldn't have caused a validatione exception.");
        }
    }
    
    public void testEmptyAccountIDFailsValidation() {
        try {
            controller.validateCustomerID("");
        } catch (IllegalArgumentException e) {
            return;
        }
        fail("Empty Customer ID should have caused a validation exception.");
    }

    public void testLongAccountIDFailsValidation() {
        try {
            controller.validateCustomerID("1234567890a");
        } catch (IllegalArgumentException e) {
            return;
        }
        fail("Customer ID > 10 characters should have caused a validation exception.");
    }
    
    public void testSomethingElseInTheController() {
        // String value = controller.findXYZ();
        // assertEquals("Value should be xyz", "xyz", value);
    }
    
    /**
     * Stubbed-out implementation of CustomerDetailsUI,
     * purely for testing the controller.
     */
    class MockCustomerDetailsUI implements CustomerDetailsUI {
        public void populateUIFromData() {
        }
    }
    
}
